<#
    .SYNOPSIS
    This script will install the ENA driver located in the same directory as
    this script.

    .EXAMPLE
    .\install.ps1

    .LEGAL
    Copyright (c) 2018 Amazon Web Services, Inc. All rights reserved.

    .LINK
    https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/enhanced-networking-ena.html
#>

# Version check OS before attempting to install. Must be 2008R2+/Windows 7+
$osVer = [System.Environment]::OSVersion.Version
if (($osVer.Major -lt 6) -or (($osVer.Major -eq 6) -and ($osVer.Minor -lt 1))) {
    Write-Error "Unsupported Version of Windows detected"
    exit -1
}

if ($env:PROCESSOR_ARCHITECTURE -ne 'AMD64') {
    Write-Error "Unsupported Windows Platform detected"
    exit -1
}

# 259 if driver is already installed.
$pnputilSuccessCodes = @(0, 259, 1641, 3010)
$pnputilExe = Join-Path $env:SystemRoot 'system32\pnputil.exe' -Resolve

# Need to support PowerShell 2 so we get script directory this way...
$scriptPath = Split-Path -Parent $MyInvocation.MyCommand.Definition
$infFile = Join-Path $scriptPath 'ena.inf' -Resolve

$pnputilProc = Start-Process -FilePath $pnputilExe -ArgumentList @('-i', '-a', "`"$infFile`"") -PassThru -Wait

$ec = $pnputilProc.ExitCode

if ($pnputilSuccessCodes -NotContains $ec) {
    Write-Error "Failed to install `"$infFile`" with pnputil exit code $ec"
    exit $ec
}

if ($ec -eq 259) {
    Write-Output "Driver already installed."
}

Write-Output "Installation of `"$infFile`" successful."

if (@(1641, 3010) -Contains $ec) {
    Write-Output "Please reboot system to complete installation of the driver."
}

exit 0


# SIG # Begin signature block
# MIIjfwYJKoZIhvcNAQcCoIIjcDCCI2wCAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCDW12bjSwjYJER2
# hD0LbTB3+DhedPgUpjyZ8IcNx6x9dqCCEd4wggU7MIIDI6ADAgECAgphIE20AAAA
# AAAnMA0GCSqGSIb3DQEBBQUAMH8xCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNo
# aW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
# cG9yYXRpb24xKTAnBgNVBAMTIE1pY3Jvc29mdCBDb2RlIFZlcmlmaWNhdGlvbiBS
# b290MB4XDTExMDQxNTE5NDUzM1oXDTIxMDQxNTE5NTUzM1owbDELMAkGA1UEBhMC
# VVMxFTATBgNVBAoTDERpZ2lDZXJ0IEluYzEZMBcGA1UECxMQd3d3LmRpZ2ljZXJ0
# LmNvbTErMCkGA1UEAxMiRGlnaUNlcnQgSGlnaCBBc3N1cmFuY2UgRVYgUm9vdCBD
# QTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMbM5XPm+9S75S0tMqbf
# 5YE/yc0lSbZxKsPVlDRnogocsF9ppkCxxLeyj9CYpKlBWTrT3JTWPNt0OKRKzE0l
# gvdKpVMSOO7zSW1xkX5jtqumX8OkhPhPYlG++MXs2ziS4wblCJEMxChBVfvLWokV
# fnHoNb9Ncgk9vjo4UFt3MRuNs8ckRZqnrG0AFFoEt7oT61EKmEFBIk5lYYeBQVCm
# eVyJ3hlKV9Uu5l0cUyx+mM0aBhakaHPQNAQTXKFx01p8VdteZOE3hzBWBOURtCmA
# EvF5OYiiAhF8J2a3iLd48soKqDirCmTCv2ZdlYTBoSUeh10aUAsgEsxBu24LUTi4
# S8sCAwEAAaOByzCByDARBgNVHSAECjAIMAYGBFUdIAAwCwYDVR0PBAQDAgGGMA8G
# A1UdEwEB/wQFMAMBAf8wHQYDVR0OBBYEFLE+w2kD+L9HAdSYJhoIAu9jZCvDMB8G
# A1UdIwQYMBaAFGL7CiFbf0NuEdoJVFBr9dKWcfGeMFUGA1UdHwROMEwwSqBIoEaG
# RGh0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3JsL3Byb2R1Y3RzL01pY3Jv
# c29mdENvZGVWZXJpZlJvb3QuY3JsMA0GCSqGSIb3DQEBBQUAA4ICAQAgjMFZ7W+c
# ay3BSj51HUVMQVAcvYDq2bCSiwYqEz9TFp5WOWqKY7Z4JHn1fbi5R6EKlsL2y72i
# Zp8G4azSeQkO/TzcrAIMcK8/G+x4ftTrSwVgJtlzYZEh7bBoY+CXEqtvoBLt2Z/S
# 2ic8s+RW+dHUgQ9xvUJ8ponczdW9laKr8ZMRfeisMSmoXWZwQZ38dcnVsxo5KtCF
# BVCLrJHKxJPLcaWdpJRvWAz6biDECDG1hZ1+gfnSPcpbGIVsCobsIgkbpXQ0T38o
# vJVKqx22mLBdCaR3dn7vp45dhPYYJMvRbabDoZzCEHWA/50y/ebPQzqC986P4XIq
# m2K3X+2VGjlcL5RtSLcBXzMvu9wtczSJBEIKHIt5+aP6F+/6oRoQ3+CywZXrXAwF
# lzs1PhiITdtsvySJjci92J97OTokoNXf0fNKGpf2pm96H7CQqbOsATmR02G3ZPE+
# VzgDr8560rWQ9a7cOZnVtjyX7abLFsd9aypMkJTmTFT9Hs0g7M5onIdY6WFgvusO
# ydUZfZ/peL0OrCF1B4+pbuCMaiprnOPnZby8LTxt3ATcZ0U2Mq8EgbyoAG5hTJXF
# XNSOjp8vwTJ0vb0RZQMHze+3XgJX2obUGig0r4hJss+l3YJWb2iqFOJZVP7/6u7v
# 6pJwImCB4yUjwJ/MD0myNapYwzrD2RaUEDCCBdswggTDoAMCAQICEAXJx3Go+N61
# O+xmHCoZRFYwDQYJKoZIhvcNAQELBQAwbDELMAkGA1UEBhMCVVMxFTATBgNVBAoT
# DERpZ2lDZXJ0IEluYzEZMBcGA1UECxMQd3d3LmRpZ2ljZXJ0LmNvbTErMCkGA1UE
# AxMiRGlnaUNlcnQgRVYgQ29kZSBTaWduaW5nIENBIChTSEEyKTAeFw0yMDA2MDIw
# MDAwMDBaFw0yMTA2MDkxMjAwMDBaMIHxMRMwEQYLKwYBBAGCNzwCAQMTAlVTMRkw
# FwYLKwYBBAGCNzwCAQITCERlbGF3YXJlMR0wGwYDVQQPDBRQcml2YXRlIE9yZ2Fu
# aXphdGlvbjEQMA4GA1UEBRMHNDE1Mjk1NDELMAkGA1UEBhMCVVMxEzARBgNVBAgT
# Cldhc2hpbmd0b24xEDAOBgNVBAcTB1NlYXR0bGUxIjAgBgNVBAoTGUFtYXpvbiBX
# ZWIgU2VydmljZXMsIEluYy4xEjAQBgNVBAsTCUFubmFwdXJuYTEiMCAGA1UEAxMZ
# QW1hem9uIFdlYiBTZXJ2aWNlcywgSW5jLjCCASIwDQYJKoZIhvcNAQEBBQADggEP
# ADCCAQoCggEBAK+ks1HM2LIMTvPr4RHbANjI48fH1dQMJcDrn08Ao00rIpBfOwdq
# BwCD6PNf5MJjpPCU7ABK7DnjPktdh2V+CQYktbA7Gy00DuTzchKAQdhcxnJvrWvV
# v1rv8l/hY7IwYXXuGxlJx92g3g339Z0kbnWes9qJOpzSy18eex8pQrUUufwWsc7W
# enCH6zUJrr16LozBxFNKlDxcPoOQR9L9WEAl47kbnnHGrgI7Ln5fm5SD+TW2+Vak
# if+pTUzBWlwTEaZokEKiuCN3T7x/nV8li6fKwDgzA4AdYFtPIoQ+ROS6igOcl3AI
# JzgTxk6gnWnJArRGr94LJBhtqfMgHo3Q4pkCAwEAAaOCAfEwggHtMB8GA1UdIwQY
# MBaAFI/ofvBtMmoABSPHcJdqOpD/a+rUMB0GA1UdDgQWBBR1JBYpXQN7Sgs+m/X3
# ke1i9mlYkzAuBgNVHREEJzAloCMGCCsGAQUFBwgDoBcwFQwTVVMtREVMQVdBUkUt
# NDE1Mjk1NDAOBgNVHQ8BAf8EBAMCB4AwEwYDVR0lBAwwCgYIKwYBBQUHAwMwewYD
# VR0fBHQwcjA3oDWgM4YxaHR0cDovL2NybDMuZGlnaWNlcnQuY29tL0VWQ29kZVNp
# Z25pbmdTSEEyLWcxLmNybDA3oDWgM4YxaHR0cDovL2NybDQuZGlnaWNlcnQuY29t
# L0VWQ29kZVNpZ25pbmdTSEEyLWcxLmNybDBLBgNVHSAERDBCMDcGCWCGSAGG/WwD
# AjAqMCgGCCsGAQUFBwIBFhxodHRwczovL3d3dy5kaWdpY2VydC5jb20vQ1BTMAcG
# BWeBDAEDMH4GCCsGAQUFBwEBBHIwcDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3Au
# ZGlnaWNlcnQuY29tMEgGCCsGAQUFBzAChjxodHRwOi8vY2FjZXJ0cy5kaWdpY2Vy
# dC5jb20vRGlnaUNlcnRFVkNvZGVTaWduaW5nQ0EtU0hBMi5jcnQwDAYDVR0TAQH/
# BAIwADANBgkqhkiG9w0BAQsFAAOCAQEAeVJORjJaa6l6tUk+SCuidC3GysRsO2Us
# Rutmg33ehivngoXDw4gxCBUHOuzzFfzd5fxjr5+HN9TIdyOASynokccY7xDhql5l
# v0wNu/lsPmWfaEiv6F0YhWmxDUvILGzERYHepHqbDvuQusSPudCXI4YZ75Oz+O++
# 7dptEw3eGeqNrZ2HE5UfUyUAj/b3gImYFiQlOQ6P4skfoU8S8SNEKBuQAJ9zF9oB
# p2vEL2VG0hEixozRMmxY73wDwy1+qrMsh/SNacwwjxpAWRzH54gv34OV6qOuLTxR
# oLo/Y9lDpybGVF2UCUXdaT/5kzkhsogpHVeeTFWKNT8y6aQY6fv7QTCCBrwwggWk
# oAMCAQICEAPxtOFfOoLxFJZ4s9fYR1wwDQYJKoZIhvcNAQELBQAwbDELMAkGA1UE
# BhMCVVMxFTATBgNVBAoTDERpZ2lDZXJ0IEluYzEZMBcGA1UECxMQd3d3LmRpZ2lj
# ZXJ0LmNvbTErMCkGA1UEAxMiRGlnaUNlcnQgSGlnaCBBc3N1cmFuY2UgRVYgUm9v
# dCBDQTAeFw0xMjA0MTgxMjAwMDBaFw0yNzA0MTgxMjAwMDBaMGwxCzAJBgNVBAYT
# AlVTMRUwEwYDVQQKEwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2Vy
# dC5jb20xKzApBgNVBAMTIkRpZ2lDZXJ0IEVWIENvZGUgU2lnbmluZyBDQSAoU0hB
# MikwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCnU/oPsrUT8WTPhID8
# roA10bbXx6MsrBosrPGErDo1EjqSkbpX5MTJ8y+oSDy31m7clyK6UXlhr0MvDbeb
# tEkxrkRYPqShlqeHTyN+w2xlJJBVPqHKI3zFQunEemJFm33eY3TLnmMl+ISamq1F
# T659H8gTy3WbyeHhivgLDJj0yj7QRap6HqVYkzY0visuKzFYZrQyEJ+d8FKh7+g+
# 03byQFrc+mo9G0utdrCMXO42uoPqMKhM3vELKlhBiK4AiasD0RaCICJ2615UOBJi
# 4dJwJNvtH3DSZAmALeK2nc4f8rsh82zb2LMZe4pQn+/sNgpcmrdK0wigOXn93b89
# OgklAgMBAAGjggNYMIIDVDASBgNVHRMBAf8ECDAGAQH/AgEAMA4GA1UdDwEB/wQE
# AwIBhjATBgNVHSUEDDAKBggrBgEFBQcDAzB/BggrBgEFBQcBAQRzMHEwJAYIKwYB
# BQUHMAGGGGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0LmNvbTBJBggrBgEFBQcwAoY9aHR0
# cDovL2NhY2VydHMuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0SGlnaEFzc3VyYW5jZUVW
# Um9vdENBLmNydDCBjwYDVR0fBIGHMIGEMECgPqA8hjpodHRwOi8vY3JsMy5kaWdp
# Y2VydC5jb20vRGlnaUNlcnRIaWdoQXNzdXJhbmNlRVZSb290Q0EuY3JsMECgPqA8
# hjpodHRwOi8vY3JsNC5kaWdpY2VydC5jb20vRGlnaUNlcnRIaWdoQXNzdXJhbmNl
# RVZSb290Q0EuY3JsMIIBxAYDVR0gBIIBuzCCAbcwggGzBglghkgBhv1sAwIwggGk
# MDoGCCsGAQUFBwIBFi5odHRwOi8vd3d3LmRpZ2ljZXJ0LmNvbS9zc2wtY3BzLXJl
# cG9zaXRvcnkuaHRtMIIBZAYIKwYBBQUHAgIwggFWHoIBUgBBAG4AeQAgAHUAcwBl
# ACAAbwBmACAAdABoAGkAcwAgAEMAZQByAHQAaQBmAGkAYwBhAHQAZQAgAGMAbwBu
# AHMAdABpAHQAdQB0AGUAcwAgAGEAYwBjAGUAcAB0AGEAbgBjAGUAIABvAGYAIAB0
# AGgAZQAgAEQAaQBnAGkAQwBlAHIAdAAgAEMAUAAvAEMAUABTACAAYQBuAGQAIAB0
# AGgAZQAgAFIAZQBsAHkAaQBuAGcAIABQAGEAcgB0AHkAIABBAGcAcgBlAGUAbQBl
# AG4AdAAgAHcAaABpAGMAaAAgAGwAaQBtAGkAdAAgAGwAaQBhAGIAaQBsAGkAdAB5
# ACAAYQBuAGQAIABhAHIAZQAgAGkAbgBjAG8AcgBwAG8AcgBhAHQAZQBkACAAaABl
# AHIAZQBpAG4AIABiAHkAIAByAGUAZgBlAHIAZQBuAGMAZQAuMB0GA1UdDgQWBBSP
# 6H7wbTJqAAUjx3CXajqQ/2vq1DAfBgNVHSMEGDAWgBSxPsNpA/i/RwHUmCYaCALv
# Y2QrwzANBgkqhkiG9w0BAQsFAAOCAQEAGTNKDIEzN9utNsnkyTq7tRsueqLi9ENC
# F56/TqFN4bHb6YHdnwHy5IjV6f4J/SHB7F2A0vDWwUPC/ncr2/nXkTPObNWyGTvm
# LtbJk0+IQI7N4fV+8Q/GWVZy6OtqQb0c1UbVfEnKZjgVwb/gkXB3h9zJjTHJDCmi
# M+2N4ofNiY0/G//V4BqXi3zabfuoxrI6Zmt7AbPN2KY07BIBq5VYpcRTV6hg5ucC
# EqC5I2SiTbt8gSVkIb7P7kIYQ5e7pTcGr03/JqVNYUvsRkG4Zc64eZ4IlguBjIo7
# j8eZjKMqbphtXmHGlreKuWEtk7jrDgRD1/X+pvBi1JlqpcHB8GSUgDGCEPcwghDz
# AgEBMIGAMGwxCzAJBgNVBAYTAlVTMRUwEwYDVQQKEwxEaWdpQ2VydCBJbmMxGTAX
# BgNVBAsTEHd3dy5kaWdpY2VydC5jb20xKzApBgNVBAMTIkRpZ2lDZXJ0IEVWIENv
# ZGUgU2lnbmluZyBDQSAoU0hBMikCEAXJx3Go+N61O+xmHCoZRFYwDQYJYIZIAWUD
# BAIBBQCgfDAQBgorBgEEAYI3AgEMMQIwADAZBgkqhkiG9w0BCQMxDAYKKwYBBAGC
# NwIBBDAcBgorBgEEAYI3AgELMQ4wDAYKKwYBBAGCNwIBFTAvBgkqhkiG9w0BCQQx
# IgQgWVBU8dB2e3tMKhjvDJ5OxP0p2Dquw6w2Fg8U/n22HeYwDQYJKoZIhvcNAQEB
# BQAEggEAkCn7s6n9nyc92HIoWlo6VHPx5U0UqpbZlQoUscPH03qXN1ddUcwjGUy4
# 6ocOE9LWRdgrFDb4htgZtmR1Zlsd0IMkuXKwbRJNToPjQOk1axfTt7F6Ob7hZETa
# nW5guh3t+wYe1c5OZdlbwL/k+UY3p8lI9uFi9BkBV/FJC7GdoPK7IhwU8l3tJP9M
# PyMeok8q/+O+xq/QP/wExGY9yuaRVuy7lSqFyM7852cot9NstwSsMfIH0bVZ9pv5
# X03+YIfuUXCWCNh3i4o6fo7pw066aIafqgSXRPxwHx2toDEshOOR1oPN1VR5qeVK
# B2OfmyAE+PpKl2b9Mxpzgh83u6Mje6GCDskwgg7FBgorBgEEAYI3AwMBMYIOtTCC
# DrEGCSqGSIb3DQEHAqCCDqIwgg6eAgEDMQ8wDQYJYIZIAWUDBAIBBQAweAYLKoZI
# hvcNAQkQAQSgaQRnMGUCAQEGCWCGSAGG/WwHATAxMA0GCWCGSAFlAwQCAQUABCBE
# Esab53ZvVpi7G31yOOT93cM7sMeythcTeP53rOrPQAIRAJHuhY6q5s5xoQuWr1ZE
# CkMYDzIwMjAwOTE1MTExMzM5WqCCC7swggaCMIIFaqADAgECAhAEzT+FaK52xhuw
# /nFgzKdtMA0GCSqGSIb3DQEBCwUAMHIxCzAJBgNVBAYTAlVTMRUwEwYDVQQKEwxE
# aWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2VydC5jb20xMTAvBgNVBAMT
# KERpZ2lDZXJ0IFNIQTIgQXNzdXJlZCBJRCBUaW1lc3RhbXBpbmcgQ0EwHhcNMTkx
# MDAxMDAwMDAwWhcNMzAxMDE3MDAwMDAwWjBMMQswCQYDVQQGEwJVUzEXMBUGA1UE
# ChMORGlnaUNlcnQsIEluYy4xJDAiBgNVBAMTG1RJTUVTVEFNUC1TSEEyNTYtMjAx
# OS0xMC0xNTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOlkNZz6qZhl
# ZBvkF9y4KTbMZwlYhU0w4Mn/5Ts8EShQrwcx4l0JGML2iYxpCAQj4HctnRXluOih
# ao7/1K7Sehbv+EG1HTl1wc8vp6xFfpRtrAMBmTxiPn56/UWXMbT6t9lCPqdVm99a
# T1gCqDJpIhO+i4Itxpira5u0yfJlEQx0DbLwCJZ0xOiySKKhFKX4+uGJcEQ7je/7
# pPTDub0ULOsMKCclgKsQSxYSYAtpIoxOzcbVsmVZIeB8LBKNcA6Pisrg09ezOXdQ
# 0EIsLnrOnGd6OHdUQP9PlQQg1OvIzocUCP4dgN3Q5yt46r8fcMbuQhZTNkWbUxlJ
# Yp16ApuVFKMCAwEAAaOCAzgwggM0MA4GA1UdDwEB/wQEAwIHgDAMBgNVHRMBAf8E
# AjAAMBYGA1UdJQEB/wQMMAoGCCsGAQUFBwMIMIIBvwYDVR0gBIIBtjCCAbIwggGh
# BglghkgBhv1sBwEwggGSMCgGCCsGAQUFBwIBFhxodHRwczovL3d3dy5kaWdpY2Vy
# dC5jb20vQ1BTMIIBZAYIKwYBBQUHAgIwggFWHoIBUgBBAG4AeQAgAHUAcwBlACAA
# bwBmACAAdABoAGkAcwAgAEMAZQByAHQAaQBmAGkAYwBhAHQAZQAgAGMAbwBuAHMA
# dABpAHQAdQB0AGUAcwAgAGEAYwBjAGUAcAB0AGEAbgBjAGUAIABvAGYAIAB0AGgA
# ZQAgAEQAaQBnAGkAQwBlAHIAdAAgAEMAUAAvAEMAUABTACAAYQBuAGQAIAB0AGgA
# ZQAgAFIAZQBsAHkAaQBuAGcAIABQAGEAcgB0AHkAIABBAGcAcgBlAGUAbQBlAG4A
# dAAgAHcAaABpAGMAaAAgAGwAaQBtAGkAdAAgAGwAaQBhAGIAaQBsAGkAdAB5ACAA
# YQBuAGQAIABhAHIAZQAgAGkAbgBjAG8AcgBwAG8AcgBhAHQAZQBkACAAaABlAHIA
# ZQBpAG4AIABiAHkAIAByAGUAZgBlAHIAZQBuAGMAZQAuMAsGCWCGSAGG/WwDFTAf
# BgNVHSMEGDAWgBT0tuEgHf4prtLkYaWyoiWyyBc1bjAdBgNVHQ4EFgQUVlMPwcYH
# p03X2G5XcoBQTOTsnsEwcQYDVR0fBGowaDAyoDCgLoYsaHR0cDovL2NybDMuZGln
# aWNlcnQuY29tL3NoYTItYXNzdXJlZC10cy5jcmwwMqAwoC6GLGh0dHA6Ly9jcmw0
# LmRpZ2ljZXJ0LmNvbS9zaGEyLWFzc3VyZWQtdHMuY3JsMIGFBggrBgEFBQcBAQR5
# MHcwJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0LmNvbTBPBggrBgEF
# BQcwAoZDaHR0cDovL2NhY2VydHMuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0U0hBMkFz
# c3VyZWRJRFRpbWVzdGFtcGluZ0NBLmNydDANBgkqhkiG9w0BAQsFAAOCAQEALoOh
# RAVKBOO5MlL62YHwGrv4CY0juT3YkqHmRhxKL256PGNuNxejGr9YI7JDnJSDTjkJ
# sCzox+HizO3LeWvO3iMBR+2VVIHggHsSsa8Chqk6c2r++J/BjdEhjOQpgsOKC2AA
# Ap0fR8SftApoU39aEKb4Iub4U5IxX9iCgy1tE0Kug8EQTqQk9Eec3g8icndcf0/p
# OZgrV5JE1+9uk9lDxwQzY1E3Vp5HBBHDo1hUIdjijlbXST9X/AqfI1579JSN3Z0a
# u996KqbSRaZVDI/2TIryls+JRtwxspGQo18zMGBV9fxrMKyh7eRHTjOeZ2ootU3C
# 7VuXgvjLqQhsUwm09zCCBTEwggQZoAMCAQICEAqhJdbWMht+QeQF2jaXwhUwDQYJ
# KoZIhvcNAQELBQAwZTELMAkGA1UEBhMCVVMxFTATBgNVBAoTDERpZ2lDZXJ0IElu
# YzEZMBcGA1UECxMQd3d3LmRpZ2ljZXJ0LmNvbTEkMCIGA1UEAxMbRGlnaUNlcnQg
# QXNzdXJlZCBJRCBSb290IENBMB4XDTE2MDEwNzEyMDAwMFoXDTMxMDEwNzEyMDAw
# MFowcjELMAkGA1UEBhMCVVMxFTATBgNVBAoTDERpZ2lDZXJ0IEluYzEZMBcGA1UE
# CxMQd3d3LmRpZ2ljZXJ0LmNvbTExMC8GA1UEAxMoRGlnaUNlcnQgU0hBMiBBc3N1
# cmVkIElEIFRpbWVzdGFtcGluZyBDQTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC
# AQoCggEBAL3QMu5LzY9/3am6gpnFOVQoV7YjSsQOB0UzURB90Pl9TWh+57ag9I2z
# iOSXv2MhkJi/E7xX08PhfgjWahQAOPcuHjvuzKb2Mln+X2U/4Jvr40ZHBhpVfgsn
# fsCi9aDg3iI/Dv9+lfvzo7oiPhisEeTwmQNtO4V8CdPuXciaC1TjqAlxa+DPIhAP
# dc9xck4Krd9AOly3UeGheRTGTSQjMF287DxgaqwvB8z98OpH2YhQXv1mblZhJymJ
# hFHmgudGUP2UKiyn5HU+upgPhH+fMRTWrdXyZMt7HgXQhBlyF/EXBu89zdZN7wZC
# /aJTKk+FHcQdPK/P2qwQ9d2srOlW/5MCAwEAAaOCAc4wggHKMB0GA1UdDgQWBBT0
# tuEgHf4prtLkYaWyoiWyyBc1bjAfBgNVHSMEGDAWgBRF66Kv9JLLgjEtUYunpyGd
# 823IDzASBgNVHRMBAf8ECDAGAQH/AgEAMA4GA1UdDwEB/wQEAwIBhjATBgNVHSUE
# DDAKBggrBgEFBQcDCDB5BggrBgEFBQcBAQRtMGswJAYIKwYBBQUHMAGGGGh0dHA6
# Ly9vY3NwLmRpZ2ljZXJ0LmNvbTBDBggrBgEFBQcwAoY3aHR0cDovL2NhY2VydHMu
# ZGlnaWNlcnQuY29tL0RpZ2lDZXJ0QXNzdXJlZElEUm9vdENBLmNydDCBgQYDVR0f
# BHoweDA6oDigNoY0aHR0cDovL2NybDQuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0QXNz
# dXJlZElEUm9vdENBLmNybDA6oDigNoY0aHR0cDovL2NybDMuZGlnaWNlcnQuY29t
# L0RpZ2lDZXJ0QXNzdXJlZElEUm9vdENBLmNybDBQBgNVHSAESTBHMDgGCmCGSAGG
# /WwAAgQwKjAoBggrBgEFBQcCARYcaHR0cHM6Ly93d3cuZGlnaWNlcnQuY29tL0NQ
# UzALBglghkgBhv1sBwEwDQYJKoZIhvcNAQELBQADggEBAHGVEulRh1Zpze/d2nyq
# Y3qzeM8GN0CE70uEv8rPAwL9xafDDiBCLK938ysfDCFaKrcFNB1qrpn4J6Jmvwmq
# YN92pDqTD/iy0dh8GWLoXoIlHsS6HHssIeLWWywUNUMEaLLbdQLgcseY1jxk5R9I
# EBhfiThhTWJGJIdjjJFSLK8pieV4H9YLFKWA1xJHcLN11ZOFk362kmf7U2GJqPVr
# lsD0WGkNfMgBsbkodbeZY4UijGHKeZR+WfyMD+NvtQEmtmyl7odRIeRYYJu6DC0r
# baLEfrvEJStHAgh8Sa4TtuF8QkIoxhhWz0E0tmZdtnR79VYzIi8iNrJLokqV2PWm
# jlIxggJNMIICSQIBATCBhjByMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMRGlnaUNl
# cnQgSW5jMRkwFwYDVQQLExB3d3cuZGlnaWNlcnQuY29tMTEwLwYDVQQDEyhEaWdp
# Q2VydCBTSEEyIEFzc3VyZWQgSUQgVGltZXN0YW1waW5nIENBAhAEzT+FaK52xhuw
# /nFgzKdtMA0GCWCGSAFlAwQCAQUAoIGYMBoGCSqGSIb3DQEJAzENBgsqhkiG9w0B
# CRABBDAcBgkqhkiG9w0BCQUxDxcNMjAwOTE1MTExMzM5WjArBgsqhkiG9w0BCRAC
# DDEcMBowGDAWBBQDJb1QXtqWMC3CL0+gHkwovig0xTAvBgkqhkiG9w0BCQQxIgQg
# XdPHR6bGaDXZfRx+2yKiPupiyc9KfeYqIoCdFfXo7aYwDQYJKoZIhvcNAQEBBQAE
# ggEAsgFT3iC+/2OcNpgYX7bU26iZjPhd1B6bQeHoRnaKEyqYFO/apqi+r2eTmFA8
# 0v/V5ZGLv0/qRpzyUvgYcSCHON9tPQrDnDZEeOLq/3ACN8ohbwmh7kHtniC2GzYm
# HHE3BC9Jnl6YVRh7aawkfrtKl5Km2yFzJH7J5bC47GDN+Xm5wlRgl3++Sm0AQL0K
# igjWHq8xBvzOP9UutQcQDDgk5sUszA4OVJY5mRZ7OnHJZClcEH3B6exwLBTy5602
# nSvb9Z0heNj5LAEizYSHMV8gsQYKAORD3ij+i7TWfNG6Y7SCZxht/eoVcCqx/Xqg
# cW5lrftN4PIeLnGBABVhZy645g==
# SIG # End signature block
